/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.mobile.api.facade.connectors;

import java.util.List;

import com.fasterxml.jackson.databind.JavaType;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.openexchange.mobile.api.facade.auth.SessionData;
import com.openexchange.mobile.api.facade.exceptions.ApiFacadeException;

public abstract class BaseListConnector<T extends AbstractResponseMto> extends AbstractConnector<List<T>> {

    private final Class<T> bodyType;

    private boolean ignoreSingleErrors;

    public BaseListConnector(RequestConfiguration configuration, SessionData sessionData, String module, Class<T> bodyType, boolean ignoreSingleErrors) {
        super(configuration, sessionData, module);
        this.bodyType = bodyType;
        this.ignoreSingleErrors = ignoreSingleErrors;
    }

    @Override
    protected JavaType getResponseBodyType(ObjectMapper mapper) {
        return mapper.getTypeFactory().constructCollectionType(List.class, this.bodyType);
    }

    @Override
    protected boolean isError(List<T> responseBodies) {
        int errorCount = 0;
        for (T responseBody : responseBodies) {
            if (responseBody.isError()) {
                errorCount++;
            }
        }
        if (ignoreSingleErrors) {
            return errorCount != 0 && errorCount == responseBodies.size();
        }
        return errorCount != 0;
    }

    @Override
    protected ApiFacadeException handleErrors(List<T> responseBody) {
        return ApiFacadeException.internalServerError("Failed request");
    }

}
